---
name: Bug report
about: Something isn't working
title: "[BUG] "
labels: bug
assignees: ''

---

**Required attestation**
- [ ] I have checked that this issue has not already been reported.
- [ ] I have confirmed this bug exists on the latest version of exif-stripper.
- [ ] I have confirmed this bug exists on the `main` branch of exif-stripper.

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Environment**
 - OS: [e.g. iOS]
 - Browser [e.g. chrome, safari]
 - Python Version [e.g. 22]
 - `pillow` version
 - `xattr` version, if not using Windows

**Additional context**
Add any other context about the problem here.
